@@ -1,4 +1,4 @@
-PELT = function(sumstat,pen=0, cost_func = "norm.mean", shape = 1, minseglen = 1,lastchangelike, lastchangecpts, numchangecpts){
+PELT = function(sumstat,pen=0, cost_func = "norm.mean", shape = 1, minseglen = 1){
   # function that uses the PELT method to calculate changes in mean where the segments in the data are assumed to be Normal
   n = length(sumstat)/3 - 1
   if(n<2){stop('Data must have atleast 2 observations to fit a changepoint model.')}
@@ -6,9 +6,9 @@ PELT = function(sumstat,pen=0, cost_func = "norm.mean", shape = 1, minseglen = 1
   storage.mode(sumstat) = 'double'
   error=0
   
-  if(missing(lastchangelike)) {lastchangelike = array(0,dim = n+1)}
-  if(missing(lastchangecpts)) {lastchangecpts = array(0,dim = n+1)}
-  if(missing(numchangecpts)) {numchangecpts = array(0,dim = n+1)}
+  lastchangelike = array(0,dim = n+1)
+  lastchangecpts = array(0,dim = n+1)
+  numchangecpts = array(0,dim = n+1)
   
   cptsout=rep(0,n) # sets up null vector for changepoint answer
   storage.mode(cptsout)='integer'
